@@ -3,20 +3,21 @@
 
     Copyright (c) 1999 - 2001 Chris Schlaeger <cs@kde.org>
 
-    This program is free software; you can redistribute it and/or
-    modify it under the terms of the GNU General Public
-    License version 2 or at your option version 3 as published by
-    the Free Software Foundation.
+ This program is free software; you can redistribute it and/or
+ modify it under the terms of the GNU General Public License as
+ published by the Free Software Foundation; either version 2 of
+ the License or (at your option) version 3 or any later version
+ accepted by the membership of KDE e.V. (or its successor approved
+ by the membership of KDE e.V.), which shall act as a proxy 
+ defined in Section 14 of version 3 of the license.
 
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+ This program is distributed in the hope that it will be useful,
+ but WITHOUT ANY WARRANTY; without even the implied warranty of
+ MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ GNU General Public License for more details.
 
+ You should have received a copy of the GNU General Public License
+ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
 #include <QClipboard>
@@ -34,7 +35,7 @@
 #include <kdebug.h>
 #include <klocale.h>
 #include <kmessagebox.h>
-#include <kmenu.h>
+#include <QMenu>
 
 #include <ksgrd/SensorManager.h>
 
@@ -352,7 +353,7 @@ KSGRD::SensorDisplay* WorkSheet::insertDisplay( DisplayType displayType, QString
             return NULL;
     }
     newDisplay->applyStyle();
-    connect(&mTimer, SIGNAL(timeout()), newDisplay, SLOT(timerTick()));
+    connect(&mTimer, &QTimer::timeout, newDisplay, &KSGRD::SensorDisplay::timerTick);
     replaceDisplay( row, column, newDisplay, rowSpan, columnSpan );
     return newDisplay;
 }
@@ -373,8 +374,8 @@ KSGRD::SensorDisplay *WorkSheet::addDisplay( const QString &hostName,
          * type we popup a menu so the user can select what display is
          * wanted. */
         if ( sensorType == "integer" || sensorType == "float" ) {
-            KMenu pm;
-            pm.addTitle( i18n( "Select Display Type" ) );
+            QMenu pm;
+            pm.addSection( i18n( "Select Display Type" ) );
             QAction *a1 = pm.addAction( i18n( "&Line graph" ) );
             QAction *a2 = pm.addAction( i18n( "&Digital display" ) );
             QAction *a3 = pm.addAction( i18n( "&Bar graph" ) );
@@ -624,14 +625,14 @@ void WorkSheet::replaceDisplay( int row, int column, KSGRD::SensorDisplay* newDi
 
     if (newDisplay->metaObject()->className() != QByteArray("DummyDisplay"))
     {
-        connect(newDisplay, SIGNAL(showPopupMenu(KSGRD::SensorDisplay*)), SLOT(showPopupMenu(KSGRD::SensorDisplay*)));
+        connect(newDisplay, &KSGRD::SensorDisplay::showPopupMenu, this, &WorkSheet::showPopupMenu);
         newDisplay->setDeleteNotifier(this);
     }
 
     // if there's only item, the tab's title should be the widget's title
     if (row == 0 && mRows == rowSpan && column == 0 && mColumns == columnSpan)
     {
-        connect(newDisplay, SIGNAL(titleChanged(QString)), SLOT(setTitle(QString)));
+        connect(newDisplay, &KSGRD::SensorDisplay::titleChanged, this, &WorkSheet::setTitle);
         setTitle(newDisplay->title());
     }
     if (isVisible())
@@ -801,4 +802,4 @@ float WorkSheet::updateInterval() const
         return 0;
 }
 
-#include "WorkSheet.moc"
+
