@@ -47,8 +47,8 @@ WorkSheetSettings::WorkSheetSettings( QWidget* parent, bool locked )
   QPushButton *okButton = buttonBox->button(QDialogButtonBox::Ok);
   okButton->setDefault(true);
   okButton->setShortcut(Qt::CTRL | Qt::Key_Return);
-  connect(buttonBox, SIGNAL(accepted()), this, SLOT(accept()));
-  connect(buttonBox, SIGNAL(rejected()), this, SLOT(reject()));
+  connect(buttonBox, &QDialogButtonBox::accepted, this, &WorkSheetSettings::accept);
+  connect(buttonBox, &QDialogButtonBox::rejected, this, &WorkSheetSettings::reject);
 
   QWidget *page = new QWidget( this );
   mainLayout->addWidget(page);
